@@ -27,22 +27,27 @@ private Q_SLOTS:
         QTest::addColumn<QString>("logo");
         QTest::addColumn<QString>("product");
 
-        QTest::newRow("Berlin U1") << 52.52 << 13.40 << s("U1") << Line::Metro << QColor(0xff52b447) << s("Berlin%20U1.svg") << s("U-Bahn.svg");
-        QTest::newRow("Berlin S7") << 52.52 << 13.40 << s("S7") << Line::RapidTransit << QColor(0xff8070b7) << s("Berlin%20S7.svg") << s("S-Bahn-Logo.svg");
+        QTest::newRow("Berlin U1") << 52.52 << 13.40 << s("U1") << Line::Metro << QColor(0xff52b447) << s("Berlin%20transit%20icons%20-%20U1.svg") << s("U-Bahn.svg");
+        QTest::newRow("Berlin S7") << 52.52 << 13.40 << s("S7") << Line::RapidTransit << QColor(0xff8070b7) << s("Berlin%20transit%20icons%20-%20S7.svg") << s("S-Bahn-Logo.svg");
+        QTest::newRow("Berlin FEX") << 52.52 << 13.40 << s("FEX") << Line::LocalTrain << QColor() << s("FEX%20VBB%20(2021).png") << QString();
+        QTest::newRow("Berlin RE1") << 52.52 << 13.40 << s("RE1") << Line::LocalTrain << QColor(0xffff0000) << s("RE1%20VBB%20(2021).png") << QString();
         QTest::newRow("Munich S1") << 48.13 << 11.58 << s("S1") << Line::RapidTransit << QColor(0xff36caec) << s("M%C3%BCnchen%20S1.svg") << s("S-Bahn-Logo.svg");
         QTest::newRow("Munich S3") << 48.13 << 11.58 << s("S3") << Line::RapidTransit << QColor(0xff862996) << s("M%C3%BCnchen%20S3.svg") << s("S-Bahn-Logo.svg");
+        QTest::newRow("Munich U3") << 48.13 << 11.58 << s("U3") << Line::Metro << QColor(0xffe66432) << s("M%C3%BCnchen%20U3.svg") << s("U-Bahnlogo%20M%C3%BCnchen.svg");
         QTest::newRow("Nurnberg S2") << 49.44 << 11.08 << s("S2") << Line::RapidTransit << QColor(0xff65b949) << QString() << s("S-Bahn-Logo.svg");
         QTest::newRow("Nurnberg U2") << 49.44 << 11.08 << s("U2") << Line::Metro << QColor(0xffff0000) << s("N%C3%BCrnberg%20U2.svg") << s("U-Bahn.svg");
+        QTest::newRow("Nurnberg tram 5") << 49.44 << 11.08 << s("5") << Line::Tramway << QColor() << s("N%C3%BCrnberg%20T5.png") << s("Tram%20N%C3%BCrnberg%20Logo.png");
         QTest::newRow("Frankfurt U8") << 50.1 << 8.66 << s("U8") << Line::Metro << QColor(0xffc77db5) << s("Frankfurt%20U8.svg") << s("U-Bahn.svg");
-        QTest::newRow("Brussels 2") << 50.83 << 4.33 << s("2") << Line::Metro << QColor(0xfff57000) << s("STIB-MIVB%20Line%202.svg") << s("Brussels%20Metro%20Logo.svg");
+        QTest::newRow("Brussels 2") << 50.83 << 4.33 << s("2") << Line::Metro << QColor(0xffed6c23) << s("STIB-MIVB%20Line%202.svg") << s("Brussels%20Metro%20Logo.svg");
         QTest::newRow("Brussels 82") << 50.83 << 4.33 << s("82") << Line::Tramway << QColor(0xff91bee7) << s("STIB-MIVB%20Line%2082.svg") << s("Brussels%20tramway%20icon.svg");
         QTest::newRow("Brussels S6") << 50.83 << 4.33 << s("S6") << Line::RapidTransit << QColor(0xff965f26) << QString() << s("NMBS%20S-Trein%20logo.svg");
         QTest::newRow("Brussels S10") << 50.83 << 4.33 << s("S10") << Line::RapidTransit << QColor(0xff000000) << QString() << s("NMBS%20S-Trein%20logo.svg");
-        QTest::newRow("Paris RER C") << 48.84 << 2.37 << s("C") << Line::RapidTransit << QColor(0xfffcd946) << s("Paris%20transit%20icons%20-%20RER%20C.svg") << s("RER.svg");
-        QTest::newRow("Paris RER D") << 48.84 << 2.37 << s("D") << Line::RapidTransit << QColor(0xff5e9620) << s("Paris%20transit%20icons%20-%20RER%20D.svg") << s("RER.svg");
-        QTest::newRow("Paris Metro 1") << 48.84 << 2.37 << s("1") << Line::Metro << QColor(0xfff2c931) << s("Paris%20Metro%201.svg") << s("Metro-M.svg");
-        QTest::newRow("Milano M5") << 45.48 << 9.18 << s("M5") << Line::Metro << QColor(0xff7956a3) << s("Milano%20linea%20M5.svg") << s("Logo%20Metropolitane%20Italia.svg");
-        QTest::newRow("Milano S1") << 45.48 << 9.18 << s("S1") << Line::RapidTransit << QColor(0xffde3d30) << s("Milano%20S1.svg") << s("Linee%20S%20di%20Milano.svg");
+        QTest::newRow("Paris RER C") << 48.84 << 2.37 << s("C") << Line::RapidTransit << QColor(0xfffcd946) << s("Paris%20transit%20icons%20-%20RER%20C.svg") << s("Paris%20transit%20icons%20-%20RER.svg");
+        QTest::newRow("Paris RER D") << 48.84 << 2.37 << s("D") << Line::RapidTransit << QColor(0xff5e9620) << s("Paris%20transit%20icons%20-%20RER%20D.svg") << s("Paris%20transit%20icons%20-%20RER.svg");
+        QTest::newRow("Paris Metro 1") << 48.84 << 2.37 << s("1") << Line::Metro << QColor(0xffffcd00) << s("Paris%20transit%20icons%20-%20M%C3%A9tro%201.svg") << s("Paris%20transit%20icons%20-%20M%C3%A9tro.svg");
+        QTest::newRow("Paris tram 1") << 48.84 << 2.37 << s("T1") << Line::Tramway << QColor(0xff216eb4) << s("Paris%20transit%20icons%20-%20Tram%201.svg") << s("Paris%20transit%20icons%20-%20Tram.svg");
+        QTest::newRow("Milano M5") << 45.48 << 9.18 << s("M5") << Line::Metro << QColor(0xffb395d0) << s("Milano%20linea%20M5.svg") << s("Logo%20Metropolitane%20Italia.svg");
+        QTest::newRow("Milano S1") << 45.48 << 9.18 << s("S1") << Line::RapidTransit << QColor(0xfffd0000) << s("Milano%20S1.svg") << s("Linee%20S%20di%20Milano.svg");
         QTest::newRow("Hannover S1") << 52.37 << 9.74 << s("S1") << Line::RapidTransit << QColor(0xff7760b0) << s("Hannover%20S1.svg") << s("S-Bahn-Logo.svg");
         QTest::newRow("Magdeburg S1") << 52.13 << 11.62 << s("S 1") << Line::RapidTransit << QColor(0xff408040) << QString() << s("S-Bahn-Logo.svg");
         QTest::newRow("Magdeburg 1") << 52.13 << 11.62 << s("1") << Line::Tramway << QColor(0xffb6005c) << s("Magdeburg%20Tram%201%20(2021).png") << QString();
@@ -53,9 +58,21 @@ private Q_SLOTS:
         QTest::newRow("Copenhagen A") << 55.67 << 12.56 << s("A") << Line::RapidTransit << QColor(0xff00bfff) << s("S-train%20service%20A.svg") << s("S-tog.svg");
         QTest::newRow("Cologne S11") << 50.94 << 6.97 << s("S11") << Line::RapidTransit << QColor(0xffef7c00) << s("NRW%20S11.svg") << s("S-Bahn-Logo.svg");
         QTest::newRow("Stuttgart S1") << 48.78 << 9.18 << s("S1") << Line::RapidTransit << QColor(0xff5c8e3c) << s("S1%20S-Bahn%20Stuttgart%20Logo%20(2021).svg") << s("S-Bahn-Logo.svg");
+        QTest::newRow("Stuttgart U6") << 48.78 << 9.18 << s("U6") << Line::RapidTransit << QColor(0xffec008c) << QString() << s("Logo%20Stadtbahn%20Stuttgart.svg");
         QTest::newRow("Barcelona L1") << 41.37 << 2.13 << s("L1") << Line::Metro << QColor(0xffe33638) << s("L1%20barcelona.svg") << s("Barcelona%20Metro%20Logo.svg");
         QTest::newRow("Toulouse Metro A") << 43.6 << 1.44 << s("A") << Line::Metro << QColor(0xffdb001b) << s("Toulouse%20line%20A%20symbol.svg") << s("Toulouse%20%22M%22%20symbol.svg");
         QTest::newRow("San Francisco BART Yellow") << 37.77 << -122.41 << s("Yellow") << Line::Metro << QColor(0xffffe800) << QString() << s("Bart-logo.svg");
+        QTest::newRow("Augsburg tram 3") << 48.33 << 10.89 << s("3") << Line::Tramway << QColor(0xffef7c00) << s("Augsburg%20Tram%203.svg") << QString();
+        QTest::newRow("Oslo T-Bane 4") << 59.94 << 10.76 << s("4") << Line::Metro << QColor(0xff0054a6) << s("Oslo%20Metro%204.svg") << s("Oslo%20T-bane%20Logo.svg");
+        QTest::newRow("Oslo tram 12") << 59.94 << 10.76 << s("12") << Line::Tramway << QColor(0xffa166aa) << s("Oslo%20Tramway%20new%2012.svg") << QString();
+        QTest::newRow("Prague C") << 50.07 << 14.47 << s("C") << Line::Metro << QColor(0xffcf003d) << s("Linka%20C%20(Praha).svg") << s("Prag%20Metro%20Logo.svg");
+        QTest::newRow("Bonn tram 61") << 50.73 << 7.1 << s("61") << Line::Tramway << QColor(0xff98c000) << QString() << s("Stadtbahn.svg");
+        QTest::newRow("Rome Metro A") << 41.8989 << 12.5089 << s("A") << Line::Metro << QColor(0xfff68b1f) << s("Metropolitana%20di%20Roma%20-%20logo%20linea%20A.svg") << s("Logo%20Metropolitane%20Italia.svg");
+        QTest::newRow("Gotenburg tram 6") << 57.7 << 11.96 << s("6") << Line::Tramway << QColor(0xfffa8719) << s("Sp%C3%A5rvagnslinje%206.svg") << QString();
+        QTest::newRow("Amsterdam line 54") << 52.37 << 4.9 << s("54") << Line::Metro << QColor(0xfffcfb05) << s("Amsterdam%20unofficial%20metro%20icon%20line%2054.svg") << s("Amsterdam%20metro%20logo.svg");
+        QTest::newRow("Thessaloniki metro 2") << 40.64 << 22.93 << s("2") << Line::Metro << QColor(0xff0070ff) << s("Thessaloniki%20Metro%20Line%202.svg") << QString();
+        QTest::newRow("Graz S5") <<  47.1 << 15.4 << s("S5") << Line::RapidTransit << QColor(0xff8d1d81) << s("S5%20Steiermark.svg") << s("S-Bahn%20Austria.svg");
+        QTest::newRow("Zurich IC 1") << 47.37 << 8.54 << s("IC 1") << Line::LongDistanceTrain << QColor(0xffe43d2e) << s("IC%201%20logo.svg") << QString();
     }
 
     void testLookup()
