@@ -37,14 +37,24 @@ static constexpr const auto MinTileCoverage = 0.1;
 
 static bool isCompatibleMode(LineInfo::Mode lhs, LineInfo::Mode rhs)
 {
-    if (lhs == LineInfo::Unknown || rhs == LineInfo::Unknown) {
+    if (lhs == rhs || lhs == LineInfo::Unknown || rhs == LineInfo::Unknown) {
         return true;
     }
     if ((lhs == LineInfo::LocalTrain && rhs == LineInfo::RapidTransit) || (lhs == LineInfo::RapidTransit && rhs == LineInfo::LocalTrain)) {
         return true;
     }
+    if (lhs == LineInfo::Train) {
+        return rhs == LineInfo::LocalTrain
+            || rhs == LineInfo::LongDistance
+            || rhs == LineInfo::RapidTransit;
+    }
+    if (rhs == LineInfo::Train) {
+        return lhs == LineInfo::LocalTrain
+            || lhs == LineInfo::LongDistance
+            || lhs == LineInfo::RapidTransit;
+    }
 
-    return lhs == rhs;
+    return false;
 }
 
 static bool isSameLine(const LineInfo &lhs, const LineInfo &rhs)
@@ -98,7 +108,8 @@ void Generator::processOSMData(OSM::DataSet &&dataSet)
     qDebug() << "got" << dataSet.relations.size() << "relations from OSM";
     // expand multi-line relations
     for (auto it = dataSet.relations.begin(); it != dataSet.relations.end();) {
-        const auto ref = OSM::tagValue(*it, "ref");
+        auto ref = OSM::tagValue(*it, "ref");
+        ref.replace(',', ';'); // wrong ref separator syntax, occurs rarely
         if (!ref.contains(';')) {
             ++it;
             continue;
@@ -188,6 +199,27 @@ void Generator::processOSMData(OSM::DataSet &&dataSet)
     }
     qDebug() << "lines after bbox merge:" << lines.size();
 
+    // check for uniqueness of Wikidata reference, even with non-intersecting bboxes
+    // can help to fix broken/split routes
+    for (auto lit = lines.begin(); lit != lines.end(); ++lit) {
+        if (!(*lit).wdId.isValid()) {
+            continue;
+        }
+        auto dupIt = std::partition(std::next(lit), lines.end(), [lit](const auto &rhs) {
+            return !isSameLine(*lit, rhs) || (*lit).wdId != rhs.wdId;
+        });
+        if (dupIt == lines.end()) {
+            continue;
+        }
+
+        for (auto it = dupIt; it != lines.end(); ++it) {
+            qDebug() << "  merging:" << *lit << "with" << *it;
+            LineInfo::merge(*lit, *it);
+        }
+        lines.erase(dupIt, lines.end());
+    }
+    qDebug() << "lines after WD reference merge:" << lines.size();
+
     augmentFromWikidata();
 }
 
@@ -226,7 +258,7 @@ static struct {
     LineInfo::Mode mode;
 } const wd_type_to_mode_map[] = {
     { wd::Q(1412403), LineInfo::RapidTransit }, // commuter rail
-    { wd::Q(1192191), LineInfo::RapidTransit }, // airport rail link
+    { wd::Q(1192191), LineInfo::Train }, // airport rail link
     { wd::Q(50331459), LineInfo::RapidTransit }, // S-Bahn line
     { wd::Q(95723), LineInfo::RapidTransit }, // S-Bahn
     { wd::Q(129172), LineInfo::LongDistance }, // ICE
@@ -277,6 +309,7 @@ static const wd::Q wd_product_types[] {
     wd::Q(1412403), // commuter rail
     wd::Q(2140646), // Stadtbahn
     wd::Q(1268865), // light rail
+    wd::Q(113455515), // automated rapid transit
 };
 
 static bool isWikidataProductType(wd::Q type)
@@ -319,12 +352,13 @@ void Generator::applyWikidataResults(std::vector<wd::Item> &&items)
             }
 
             // collect possible product types
-            const auto partOfIds = item.values<wd::Q>(wd::P::partOf);
-            for (const auto &id : partOfIds) {
-                wdPartOfIds.insert(id);
-                (*rit).wdProducts.push_back(id);
+            for (const wd::P p : {wd::P(wd::P::partOf), wd::P(16)}) {
+                for (const auto &id : item.values<wd::Q>(p)) {
+                    wdPartOfIds.insert(id);
+                    (*rit).wdProducts.push_back(id);
 
-                mode = std::max(mode, modeFromWikidataType(id));
+                    mode = std::max(mode, modeFromWikidataType(id));
+                }
             }
 
             // merge information
@@ -479,14 +513,21 @@ void Generator::verifyImageMetaData(std::vector<wd::Image> &&images)
 {
     const QStringList valid_licenses({
         QStringLiteral("cc0"),
+        QStringLiteral("copyrighted free use"),
         QStringLiteral("public domain"),
         QStringLiteral("cc by 3.0"),
+        QStringLiteral("cc by 3.0 it"),
         QStringLiteral("cc by-sa 3.0"),
         QStringLiteral("cc by-sa 3.0 de"),
         QStringLiteral("cc-by-sa-3.0"),
         QStringLiteral("cc by-sa 4.0"),
     });
 
+    // things that for whatever reason managed to bypass all generic checks but that we don't want still
+    const QStringList excluded_names({
+        QStringLiteral("S-Bahn München Logo ohne DB (2022).svg"), // cheats around the aspect ratio check, fallback gives us the standard S-Bahn logo
+    });
+
     for (auto &image : images) {
         const auto name = image.name();
         const auto fileSize = image.fileSize();
@@ -513,6 +554,11 @@ void Generator::verifyImageMetaData(std::vector<wd::Image> &&images)
             continue;
         }
 
+        if (excluded_names.contains(name)) {
+            qWarning() << "dropping logo" << name;
+            continue;
+        }
+
         wdImages[name] = std::move(image);
    }
    images.clear();
@@ -704,6 +750,11 @@ static QByteArray modeToString(LineInfo::Mode mode)
             return "LineMetaDataContent::Subway";
         case LineInfo::RapidTransit:
             return "LineMetaDataContent::RapidTransit";
+        case LineInfo::Train:
+        case LineInfo::LocalTrain:
+            return "LineMetaDataContent::LocalTrain";
+        case LineInfo::LongDistance:
+            return "LineMetaDataContent::LongDistanceTrain";
         default:
             assert(false);
     }
@@ -880,7 +931,7 @@ int main(int argc, char **argv)
         QCoreApplication::exit(1);
     }
     OSM::DataSet dataSet;
-    auto reader = OSM::IO::readerForMimeType(u"vnd.openstreetmap.data+o5m", &dataSet);
+    auto reader = OSM::IO::readerForMimeType(u"application/vnd.openstreetmap.data+o5m", &dataSet);
     assert(reader);
     reader->read(f.map(0, f.size()), f.size());
 
