@@ -24,10 +24,10 @@ bool LineInfo::isUseful(const LineInfo& info)
     switch (info.mode) {
         case Unknown:
             return false;
+        case Train:
         case LongDistance:
         case LocalTrain:
-            return false;
-            //return !info.lineLogos.empty() || !info.productLogos.empty();
+            return !info.lineLogos.empty();
         case RapidTransit:
         case Tram:
         case Subway:
@@ -80,7 +80,7 @@ LineInfo LineInfo::fromRelation(const OSM::Relation &rel)
         return info;
     }
 
-    info.name = QString::fromUtf8(OSM::tagValue(rel, "ref"));
+    info.name = QString::fromUtf8(OSM::tagValue(rel, "ref")).trimmed();
     const auto colStr = OSM::tagValue(rel, "colour");
     if (!colStr.isEmpty()) {
         info.color = QColor(QString::fromUtf8(colStr));
