@@ -33,10 +33,38 @@ class KPUBLICTRANSPORT_EXPORT PathSection
 
     /** The length of this path section in meters. */
     Q_PROPERTY(int distance READ distance STORED false)
+    /** The overall direction of this section in degree. */
+    Q_PROPERTY(int direction READ direction STORED false)
+
+    /** Floor level change during this path section.
+     *  Negative values indicate going down, positive values indicate going up
+     */
+    KPUBLICTRANSPORT_PROPERTY(int, floorLevelChange, setFloorLevelChange)
+
+public:
+    /** Maneuver associated with a path section. */
+    enum Maneuver {
+        Move, ///< Move/drive with the default mode of transport for this path
+        Stairs, ///< Walk up or down stairs
+        Elevator, ///< Take an elevator
+        Escalator, ///< Take an escalator
+    };
+    Q_ENUM(Maneuver)
+    /** Movement maneuver for this path section. */
+    KPUBLICTRANSPORT_PROPERTY(Maneuver, maneuver, setManeuver)
 
 public:
     /** Length of this path section in meters. */
     int distance() const;
+    /** The overall direction of this section in degree.
+     *  @returns 0-359 for valid results, -1 for sections with no direction (e.g. points).
+     */
+    int direction() const;
+
+    /** First point on the path of this section. */
+    QPointF startPoint() const;
+    /** Last point on the path of this section. */
+    QPointF endPoint() const;
 
     /** Serializes one path section section to JSON. */
     static QJsonObject toJson(const PathSection &section);
@@ -83,6 +111,11 @@ public:
     /** Length of this path in meters. */
     int distance() const;
 
+    /** First point on this path. */
+    QPointF startPoint() const;
+    /** Last point on this path. */
+    QPointF endPoint() const;
+
     /** Serializes one path object to JSON. */
     static QJsonObject toJson(const Path &path);
     /** Deserialize an object from JSON. */
