@@ -41,6 +41,7 @@ public:
 
     std::vector<IndividualTransport> accessModes = { {IndividualTransport::Walk} };
     std::vector<IndividualTransport> egressModes = { {IndividualTransport::Walk} };
+    std::vector<Line::Mode> lineModes;
 };
 }
 
@@ -173,7 +174,7 @@ void JourneyRequest::setAccessModes(std::vector<IndividualTransport> &&accessMod
     d->accessModes = std::move(accessModes);
 }
 
-void JourneyRequest::setAccessModes(const QVariantList &accessModesVariant)
+void JourneyRequest::setAccessModesVariant(const QVariantList &accessModesVariant)
 {
     d.detach();
     d->accessModes = IndividualTransport::fromVariant(accessModesVariant);
@@ -195,12 +196,39 @@ void JourneyRequest::setEgressModes(std::vector<IndividualTransport>&& egressMod
     d->egressModes = std::move(egressModes);
 }
 
-void JourneyRequest::setEgressModes(const QVariantList &egressModesVariant)
+void JourneyRequest::setEgressModesVariant(const QVariantList &egressModesVariant)
 {
     d.detach();
     d->egressModes = IndividualTransport::fromVariant(egressModesVariant);
 }
 
+const std::vector<Line::Mode>& JourneyRequest::lineModes() const
+{
+    return d->lineModes;
+}
+
+void JourneyRequest::setLineModes(std::vector<Line::Mode> &&lineModes)
+{
+    d.detach();
+    d->lineModes = std::move(lineModes);
+    std::sort(d->lineModes.begin(), d->lineModes.end());
+    d->lineModes.erase(std::unique(d->lineModes.begin(), d->lineModes.end()), d->lineModes.end());
+}
+
+QVariantList JourneyRequest::lineModesVariant() const
+{
+    return toVariantList(d->lineModes);
+}
+
+void JourneyRequest::setLineModesVariant(const QVariantList &lineModes)
+{
+    auto l = std::move(d->lineModes);
+    l.clear();
+    l.reserve(lineModes.size());
+    std::transform(lineModes.begin(), lineModes.end(), std::back_inserter(l), [](const auto &mode) { return static_cast<Line::Mode>(mode.toInt()); });
+    setLineModes(std::move(l));
+}
+
 QString JourneyRequest::cacheKey() const
 {
     QCryptographicHash hash(QCryptographicHash::Sha1);
@@ -225,6 +253,11 @@ QString JourneyRequest::cacheKey() const
         hash.addData(QMetaEnum::fromType<IndividualTransport::Qualifier>().valueToKey(it.qualifier()));
     }
 
+    hash.addData("MODES");
+    for (const auto &mode : d->lineModes) {
+        hash.addData(QMetaEnum::fromType<Line::Mode>().valueToKey(mode));
+    }
+
     return QString::fromUtf8(hash.result().toHex());
 }
 
